This crate provides the UIModule, which can be added to your application along with an update_ui-system, which you must implement yourself.
For ease of use the crate also reexports iced and iced_winit.
The UIModule also adds the WinitModule to your App, so you can draw your application to a window.
When using this with iced, make sure to read the iced_winit documentation for e.g. converting winit windows to iced windows.
Re-exports
pub use iced;pub use iced_winit;
Structs
- Adds support for creating ui